@@ -172,6 +172,7 @@ class G90Sensor:  # pylint:disable=too-many-instance-attributes
         self._subindex = subindex
         self._occupancy = False
         self._state_callback = None
+        self._low_battery_callback = None
         self._proto_idx = proto_idx
         self._extra_data = None
 
@@ -217,6 +218,25 @@ class G90Sensor:  # pylint:disable=too-many-instance-attributes
         """
         self._state_callback = value
 
+    @property
+    def low_battery_callback(self):
+        """
+        Returns callback the sensor might have set for low battery condition.
+
+        :return: Sensor's low battery callback
+        :rtype: object
+        """
+        return self._low_battery_callback
+
+    @low_battery_callback.setter
+    def low_battery_callback(self, value):
+        """
+        Sets callback for the low battery condition reported by the sensor.
+
+        :param object value: Sensor's low battery callback
+        """
+        self._low_battery_callback = value
+
     @property
     def occupancy(self):
         """
